==> zio-aws-dataexchange_2.13-5.17.102.9-sources.jar: zio/aws/dataexchange/model/GetAssetRequest.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetAssetRequest(
    assetId: __string,
    dataSetId: __string,
    revisionId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.GetAssetRequest = {
    import GetAssetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.GetAssetRequest
      .builder()
      .assetId(__string.unwrap(assetId): java.lang.String)
      .dataSetId(__string.unwrap(dataSetId): java.lang.String)
      .revisionId(__string.unwrap(revisionId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.GetAssetRequest.ReadOnly =
    zio.aws.dataexchange.model.GetAssetRequest.wrap(buildAwsValue())
}
object GetAssetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.GetAssetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.GetAssetRequest =
      zio.aws.dataexchange.model.GetAssetRequest(assetId, dataSetId, revisionId)
    def assetId: __string
    def dataSetId: __string
    def revisionId: __string
    def getAssetId: ZIO[Any, Nothing, __string] = ZIO.succeed(assetId)
    def getDataSetId: ZIO[Any, Nothing, __string] = ZIO.succeed(dataSetId)
    def getRevisionId: ZIO[Any, Nothing, __string] = ZIO.succeed(revisionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.GetAssetRequest
  ) extends zio.aws.dataexchange.model.GetAssetRequest.ReadOnly {
    override val assetId: __string =
      zio.aws.dataexchange.model.primitives.__string(impl.assetId())
    override val dataSetId: __string =
      zio.aws.dataexchange.model.primitives.__string(impl.dataSetId())
    override val revisionId: __string =
      zio.aws.dataexchange.model.primitives.__string(impl.revisionId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.GetAssetRequest
  ): zio.aws.dataexchange.model.GetAssetRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-dataexchange_2.13-5.17.183.1-sources.jar: zio/aws/dataexchange/model/GetAssetRequest.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetAssetRequest(
    assetId: __string,
    dataSetId: __string,
    revisionId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.GetAssetRequest = {
    import GetAssetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.GetAssetRequest
      .builder()
      .assetId(assetId: java.lang.String)
      .dataSetId(dataSetId: java.lang.String)
      .revisionId(revisionId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.GetAssetRequest.ReadOnly =
    zio.aws.dataexchange.model.GetAssetRequest.wrap(buildAwsValue())
}
object GetAssetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.GetAssetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.GetAssetRequest =
      zio.aws.dataexchange.model.GetAssetRequest(assetId, dataSetId, revisionId)
    def assetId: __string
    def dataSetId: __string
    def revisionId: __string
    def getAssetId: ZIO[Any, Nothing, __string] = ZIO.succeed(assetId)
    def getDataSetId: ZIO[Any, Nothing, __string] = ZIO.succeed(dataSetId)
    def getRevisionId: ZIO[Any, Nothing, __string] = ZIO.succeed(revisionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.GetAssetRequest
  ) extends zio.aws.dataexchange.model.GetAssetRequest.ReadOnly {
    override val assetId: __string = impl.assetId(): __string
    override val dataSetId: __string = impl.dataSetId(): __string
    override val revisionId: __string = impl.revisionId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.GetAssetRequest
  ): zio.aws.dataexchange.model.GetAssetRequest.ReadOnly = new Wrapper(impl)
}
